# Contributors

* JupyterLab Bot ([@jupyterlab-bot](https://crowdin.com/profile/jupyterlab-bot))
* Yuliia Pavliuk ([@pav.yulia](https://crowdin.com/profile/pav.yulia))
* Steven Silvester ([@blink1073](https://crowdin.com/profile/blink1073))
* Alina ([@astromavka](https://crowdin.com/profile/astromavka))
* Дмитро Сергійович Залатухін ([@dmytro.zalatukhin](https://crowdin.com/profile/dmytro.zalatukhin))
* Denys ([@Veydzher](https://crowdin.com/profile/Veydzher))
* Anhelina_Ilina ([@Anhelina_Ilina](https://crowdin.com/profile/Anhelina_Ilina))
* Daryna_kh ([@Daryna_kh](https://crowdin.com/profile/Daryna_kh))
* Владислава Бабко ([@vladyslava.babko](https://crowdin.com/profile/vladyslava.babko))
* seventeenfive36 ([@seventeenfive36](https://crowdin.com/profile/seventeenfive36))
* Олександрина Войток ([@oleksandryna.voitok](https://crowdin.com/profile/oleksandryna.voitok))
* Vladyslav Sazhen ([@astrochumak](https://crowdin.com/profile/astrochumak))
* Valentyna_Boberska ([@Valentyna_Boberska](https://crowdin.com/profile/Valentyna_Boberska))
* yelizaveta_yakubovska ([@yelizaveta_yakubovska](https://crowdin.com/profile/yelizaveta_yakubovska))
* EvelinaRevenko ([@EvelinaRevenko](https://crowdin.com/profile/EvelinaRevenko))
* khrystynaboitsun ([@khrystynaboitsun](https://crowdin.com/profile/khrystynaboitsun))
* Oleksii Burdin ([@oleksiburdin](https://crowdin.com/profile/oleksiburdin))
* sahanshiii ([@sahanshiii](https://crowdin.com/profile/sahanshiii))
* Viktoriia Nesvavol ([@nesvavol.viktoria](https://crowdin.com/profile/nesvavol.viktoria))
* Nathalie Rud ([@talka](https://crowdin.com/profile/talka))
* Каріна Степанівна Іляшко ([@karina.iliashko](https://crowdin.com/profile/karina.iliashko))
* lodka ([@lodka](https://crowdin.com/profile/lodka))
* Kate Nevirkovets ([@kateryna.nvrkvts](https://crowdin.com/profile/kateryna.nvrkvts))
* Ruslana Tarasiuk ([@R_Tarasiuk](https://crowdin.com/profile/R_Tarasiuk))
* Olia Tkachuk ([@ms_lechka](https://crowdin.com/profile/ms_lechka))
* Serhiy Dmytryshyn ([@dies](https://crowdin.com/profile/dies))
* Anastasiia.Dmytriieva ([@Anastasiia.Dmytriieva](https://crowdin.com/profile/Anastasiia.Dmytriieva))
* d.yankovskyi ([@d.yankovskyi](https://crowdin.com/profile/d.yankovskyi))
* Златослава Олександрівна Цибульська ([@zlatoslava.tsybulska](https://crowdin.com/profile/zlatoslava.tsybulska))
